@@ -1,12 +1,12 @@
 class BaseClient(type):
     def __init__(cls, name, bases, attrs):
         super(BaseClient, cls).__init__(name)
-        if not hasattr(cls, 'client'):
+        if not hasattr(cls, "client"):
             cls.client = []
         else:
             cls.register(cls)  # Called when a client class is imported
 
-    def register(cls, client):
+    def register(cls, client=None):
         cls.client.append(client())
 
 
@@ -16,6 +16,7 @@ class Client(object, metaclass=BaseClient):
     logger = None
     hass_api = None
     use_timer = True
+    plant_id_list = []
 
     def initialize(self):
         pass
